/**
 *    HTMLWriter.java
 *    Copyright (C) 2010 New Zealand Digital Library, http://expeditee.org
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.expeditee.io;

import java.io.IOException;
import java.util.List;

import org.expeditee.actions.Misc;
import org.expeditee.core.Dimension;
import org.expeditee.core.Image;
import org.expeditee.core.Point;
import org.expeditee.gio.EcosystemManager;
import org.expeditee.gio.GraphicsManager;
import org.expeditee.gui.FrameIO;
import org.expeditee.items.FramePicture;
import org.expeditee.items.Item;
import org.expeditee.items.Picture;
import org.expeditee.items.Text;

public class HTMLWriter extends AbstractHTMLWriter {

	@Override
	protected void writeTitle(Text toWrite, List<Item> items)
			throws IOException {
		int indent = getIndent();
		if (indent == 0)
			return;

		String heading = toWrite.getText();
		String tag = "h" + indent;
		// indenting for tag
		indent();
		_writer.write("<" + tag + ">" + heading + "</" + tag + ">"
				+ ItemWriter.NEW_LINE);
	}

	@Override
	protected void writeText(Text text) throws IOException {
		indent();
		_writer.write("<p>");
		_writer.write(text.getText().replace('\n', ' '));
		_writer.write("</p>" + ItemWriter.NEW_LINE);
	}

	@Override
	protected void writePicture(Picture pic) throws IOException {
		// TODO handle different colored @f's of the same frame
		// TODO handle cropped images
		Image image = null;

		if (pic instanceof FramePicture || pic.isCropped()) {
			image = pic.getImage();
			// Crop the image
			Image bufferedImage = Image.createImage(pic.getUnscaledWidth(), pic.getUnscaledHeight());
			GraphicsManager g = EcosystemManager.getGraphicsManager();
			g.pushDrawingSurface(bufferedImage);
			g.drawImage(image,
						new Point(0, 0),
						new Dimension(pic.getUnscaledWidth(), pic.getUnscaledHeight()),
						0.0,
						pic.getStart(),
						new Dimension(pic.getEnd().getX() - pic.getStart().getX(), pic.getEnd().getY() - pic.getStart().getY()));
			g.popDrawingSurface();
			image = bufferedImage;
		} else {
			image = pic.getImage();
		}

		String filesFolder = getFilesFolder();
		String fileName;
		// If its a bufferedImage then just write it out to the files directory
		// This means it is probably a FrameImage
		if (!image.isStoredOnDisk()) {
			String link = pic.getAbsoluteLink();
			// Account for the possibility of an unlinked buffered image
			fileName = link == null ? ("Image" + pic.getID()) : link;
			fileName = Misc.SaveImage(image, "PNG",	FrameIO.EXPORTS_DIR + filesFolder, fileName);
		} else {// It is a normal Image stored somewhere
			fileName = pic.getName();

			String oldImageName = FrameIO.IMAGES_PATH + fileName;
			String newImageName = FrameIO.EXPORTS_DIR + filesFolder + fileName;
			try {
				FrameIO.copyFile(oldImageName, newImageName);
			} catch (Exception e) {
				filesFolder = "";
			}
			if (filesFolder.equals("")) {
				filesFolder = "../images/";
			}
		}
		indent();
		StringBuffer imageTag = new StringBuffer("<img src=\"");
		imageTag.append(filesFolder).append(fileName);
		imageTag.append("\" height=").append(pic.getHeight());
		imageTag.append(" width=").append(pic.getWidth());
		imageTag.append(" border=1>");
		_writer.write(imageTag.toString());
		_writer.write(ItemWriter.NEW_LINE);
	}
}
