/**
 *    TemplateSettings.java
 *    Copyright (C) 2010 New Zealand Digital Library, http://expeditee.org
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.expeditee.settings.templates;

import org.expeditee.core.Colour;
import org.expeditee.gui.DisplayController;
import org.expeditee.gui.Frame;
import org.expeditee.gui.FrameUtils;
import org.expeditee.gui.FreeItems;
import org.expeditee.items.Item;
import org.expeditee.items.ItemUtils;
import org.expeditee.items.Text;
import org.expeditee.setting.ArraySetting;
import org.expeditee.setting.FrameSetting;
import org.expeditee.setting.StringSetting;
import org.expeditee.setting.TextSetting;

public class TemplateSettings {

	public static final StringSetting DefaultFrame = new StringSetting("The default frame", null) {
		@Override
		public boolean setSetting(Text text) {
			_value = FrameUtils.getLink(text, _value);
			return true;
		}
	};
	
	public static final FrameSetting CursorFrame = new FrameSetting("Items on this frame will be used as the cursor (clearing the frame or removing the link will default back to a normal cursor)", "CursorFrame") {
		@Override
		public void run(Frame frame) {
			FreeItems.getCursor().addAll(ItemUtils.CopyItems(frame.getAllItems()));
			for (Item i : FreeItems.getCursor()) {
				i.setParent(null);
			}
			DisplayController.setCursor(Item.HIDDEN_CURSOR);
			DisplayController.setCursor(Item.DEFAULT_CURSOR);
		}
	};
	
	public static final ArraySetting<Colour> ColorWheel = new ArraySetting<Colour>("The colours of items in the child frame are used to populate the colour wheel",
			"ColorWheel", new Colour[] { Colour.BLACK, Colour.RED, Colour.BLUE, Item.GREEN, Colour.MAGENTA, Colour.YELLOW.darker(), Colour.WHITE }) {
		@Override
		public boolean setSetting(Text text) {
			Frame child = text.getChild();
    		if (child == null) {
    			return false;
    		}
    		_value = FrameUtils.getColorWheel(child);
    		return true;
		}
	};
	
	public static final ArraySetting<Colour> FillColorWheel = new ArraySetting<Colour>("The colours of items in the child frame are used to populate the colour wheel",
			"FillColorWheel", new Colour[] { Colour.FromRGB255(255, 150, 150), Colour.FromRGB255(150, 150, 255), Colour.FromRGB255(150, 255, 150),
			Colour.FromRGB255(255, 150, 255), Colour.FromRGB255(255, 255, 100), Colour.WHITE, Colour.BLACK }) {
		@Override
		public boolean setSetting(Text text) {
			Frame child = text.getChild();
    		if (child == null) {
    			return false;
    		}
    		_value = FrameUtils.getColorWheel(child);
    		return true;
		}
	};
	
	public static final ArraySetting<Colour> BackgroundColorWheel = new ArraySetting<Colour>("The colours of items in the child frame are used to populate the colour wheel",
			"BackgroundColorWheel",
			new Colour[] { Colour.FromRGB255(235, 235, 235), Colour.FromRGB255(225, 225, 255), Colour.FromRGB255(195, 255, 255),
					Colour.FromRGB255(225, 255, 225), Colour.FromRGB255(255, 255, 195), Colour.FromRGB255(255, 225, 225),
					Colour.FromRGB255(255, 195, 255), Colour.WHITE, Colour.GREY, Colour.DARK_GREY, Colour.BLACK, null }) {
		@Override
		public boolean setSetting(Text text) {
			Frame child = text.getChild();
    		if (child == null) {
    			return false;
    		}
    		_value = FrameUtils.getColorWheel(child);
    		return true;
		}
	};
	
	public static final TextSetting ItemTemplate = new TextSetting("Template for normal text items", "ItemTemplate") {
		@Override
		public Text generateText() {
			return new Text("ItemTemplate");
		}
	};
	public static final TextSetting AnnotationTemplate = new TextSetting("Template for annotation text items", "AnnotationTemplate") {
		@Override
		public Text generateText() {
			Text t = new Text("AnnotationTemplate");
    		t.setColor(Colour.GREY);
    		return t;
		}
	};

	public static final TextSetting CommentTemplate = new TextSetting("Template for code comment text items", "CommentTemplate") {
		@Override
		public Text generateText() {
			Text t = new Text("CommentTemplate");
    		t.setColor(Colour.GREEN.darker());
    		return t;
		}
	};

	public static final TextSetting StatTemplate = new TextSetting("Template for statistics (e.g. extracted attributes) text items", "StatTemplate") {
		@Override
		public Text generateText() {
			Text t = new Text("StatsTemplate");
    		t.setColor(Colour.BLACK);
    		t.setBackgroundColor(new Colour(0.9F, 0.9F, 0.9F));
    		t.setFamily(Text.MONOSPACED_FONT);
    		t.setSize(14);
    		return t;
		}
	};
	
	public static final TextSetting TitleTemplate = new TextSetting("Template for Title text item", "TitleTemplate") {
		@Override
		public Text generateText() {
			Text t = new Text("TitleTemplate");
			t.setSize(30);
    		t.setFontStyle("Bold");
    		t.setFamily("SansSerif");
    		t.setColor(Colour.BLUE);
    		t.setPosition(25, 50);
    		return t;
		}
	};
	
	public static final TextSetting DotTemplate = new TextSetting("Template for dot items", "DotTemplate") {
		@Override
		public Text generateText() {
			return new Text("DotTemplate");
		}
	};
	
	public static final TextSetting TooltipTemplate = new TextSetting("Template for tooltips", "TooltipTemplate") {
		@Override
		public Text generateText() {
			Text t = new Text("TooltipTemplate");
    		t.setColor(Colour.BLACK);
    		t.setBackgroundColor(new Colour(0.7F, 0.7F, 0.9F));
    		// t.setFamily(Text.MONOSPACED_FONT);
    		t.setSize(14);
    		return t;
		}
	};
}
